aboutsummaryrefslogtreecommitdiff
path: root/src/net/dial_test.go
diff options
context:
space:
mode:
authorElias Naur <mail@eliasnaur.com>2019-05-02 03:12:12 -0400
committerElias Naur <mail@eliasnaur.com>2019-05-03 13:59:16 +0000
commit9f513254ae92e2a62c3197cf16f7f22a8ca2879a (patch)
treed2d6c812e76158b4dd256813c2ef1c497ef94deb /src/net/dial_test.go
parentbd384d42c11d5b3ec36dbc325ec8d350ea1f1b82 (diff)
downloadgo-9f513254ae92e2a62c3197cf16f7f22a8ca2879a.tar.gz
go-9f513254ae92e2a62c3197cf16f7f22a8ca2879a.zip
net: skip DNS tests on self-hosted Android
They were already skipped on tethered Android builders because the tests are gated on GO_BUILDER_NAME being set and the Android exec wrapper does not propagate GO_BUILDER_NAME. Updates #31722 Change-Id: Ifd2c7daecc19a4e540d86d1f38083f43cc3e6b15 Reviewed-on: https://go-review.googlesource.com/c/go/+/175177 Run-TryBot: Elias Naur <mail@eliasnaur.com> TryBot-Result: Gobot Gobot <gobot@golang.org> Reviewed-by: Ian Lance Taylor <iant@golang.org>
Diffstat (limited to 'src/net/dial_test.go')
-rw-r--r--src/net/dial_test.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/net/dial_test.go b/src/net/dial_test.go
index 3646ab9815..1bf96fd3ce 100644
--- a/src/net/dial_test.go
+++ b/src/net/dial_test.go
@@ -973,11 +973,11 @@ func TestDialerControl(t *testing.T) {
}
// mustHaveExternalNetwork is like testenv.MustHaveExternalNetwork
// except that it won't skip testing on non-iOS builders.
func mustHaveExternalNetwork(t *testing.T) {
t.Helper()
- ios := runtime.GOOS == "darwin" && (runtime.GOARCH == "arm" || runtime.GOARCH == "arm64")
- if testenv.Builder() == "" || ios {
+ mobile := runtime.GOOS == "android" || runtime.GOOS == "darwin" && (runtime.GOARCH == "arm" || runtime.GOARCH == "arm64")
+ if testenv.Builder() == "" || mobile {
testenv.MustHaveExternalNetwork(t)
}
}
@@ -973,11 +973,11 @@ func TestDialerControl(t *testing.T) {
}
// mustHaveExternalNetwork is like testenv.MustHaveExternalNetwork
-// except that it won't skip testing on non-iOS builders.
+// except that it won't skip testing on non-mobile builders.
func mustHaveExternalNetwork(t *testing.T) {
t.Helper()